@@ -1,6 +1,6 @@
 /*
- * $Id: options.c,v 1.9 2013-01-18 08:33:48-08 bll Exp $
- * $Source: /home/bll/DI/di/C/RCS/options.c,v $
+ * $Id$
+ * $Source$
  *
  * Copyright 1994-2013 Brad Lanam, Walnut Creek, CA
  */
@@ -644,7 +644,7 @@ parseList (list, str)
     ocount = list->count;
     list->count += count;
     ncount = list->count;
-    list->list = (char **) _realloc ((char *) list->list,
+    list->list = (char **) di_realloc ((char *) list->list,
             (Size_t) list->count * sizeof (char *));
     if (list->list == (char **) NULL)
     {
