@@ -1,6 +1,6 @@
 /*
- * $Id: realloc.c,v 1.8 2010-07-14 01:54:55-07 bll Exp $
- * $Source: /home/bll/DI/di/RCS/realloc.c,v $
+ * $Id$
+ * $Source$
  * Copyright 1994-2010 Brad Lanam, Walnut Creek, CA
  */
 
@@ -29,9 +29,9 @@
 
 _pvoid
 #if _proto_stdc
-_realloc (_pvoid ptr, Size_t size)
+di_realloc (_pvoid ptr, Size_t size)
 #else
-_realloc (ptr, size)
+di_realloc (ptr, size)
     _pvoid      ptr;
     Size_t      size;
 #endif
