@@ -67,6 +67,7 @@ for d in C D; do
         #  clang: 'warning: unknown warning option'
         #  clang: X warnings? generated.
         #  many: unrecognized #pragma ignored
+        #  miros:gcc: someone does not honour COPTS correctly
         # D:
         #  FLAGS= (makefile)
         #  --     (makefile)
@@ -108,6 +109,7 @@ for d in C D; do
           grep -v 'warning.*generated\.' |
           grep -v 'Unknown option.*-Wno-unused-parameter.*ignored' |
           grep -v 'unrecognized #pragma ignored' |
+          grep -v 'someone does not honour COPTS correctly' |
           grep -v FLAGS= |
           grep -v -- '--' |
           cat > make_extra.log
